pub struct ConnectionPolicySource { /* private fields */ }Expand description
A PolicySource reading the authz database over a peer connection.
Implementations
Sourceimpl ConnectionPolicySource
impl ConnectionPolicySource
Sourcepub fn new(connection: Arc<Connection>) -> Self
pub fn new(connection: Arc<Connection>) -> Self
Reads policy from the database connection is synced to.