pub struct CachedPeerStorage { /* private fields */ }Expand description
Storage decorator that caches blob reads while always delegating roots.
Implementations
Sourceimpl CachedPeerStorage
impl CachedPeerStorage
Sourcepub fn open(
storage: Arc<dyn PeerStorage>,
config: &SegmentCacheConfig,
) -> Result<Self>
pub fn open( storage: Arc<dyn PeerStorage>, config: &SegmentCacheConfig, ) -> Result<Self>
Opens a cache around peer storage.
Errors
Returns an error for invalid configuration, inaccessible storage, or an already-owned cache directory.
Sourcepub fn metrics(&self) -> Arc<SegmentCacheMetrics>
pub fn metrics(&self) -> Arc<SegmentCacheMetrics>
Returns cache counters for a metrics adapter.