pub struct SegmentSource<S> { /* private fields */ }Expand description
Read-through segment source over a blob/root store.
Implementations
Sourceimpl<S: BlobStore + RootStore> SegmentSource<S>
impl<S: BlobStore + RootStore> SegmentSource<S>
Sourcepub fn index_root(&self, db: &str) -> Result<Option<DbRoot>, StoreError>
pub fn index_root(&self, db: &str) -> Result<Option<DbRoot>, StoreError>
Reads the current published index root for db.
Errors
Returns an error when the root store cannot be read.
Sourcepub fn segment(
&self,
root: &DbRoot,
order: IndexOrder,
) -> Result<Option<Arc<[u8]>>, StoreError>
pub fn segment( &self, root: &DbRoot, order: IndexOrder, ) -> Result<Option<Arc<[u8]>>, StoreError>
Loads the segment for one index order of a published root, through the cache.
Errors
Returns an error when the blob cannot be loaded.
Sourcepub fn segment_keys(bytes: &[u8]) -> Result<Vec<Vec<u8>>, StoreError>
pub fn segment_keys(bytes: &[u8]) -> Result<Vec<Vec<u8>>, StoreError>
Decodes a segment’s length-prefixed key entries.
Errors
Returns StoreError::CorruptBlob-free decode failures as None
entries never occur; malformed framing yields an error.