pub struct Admin { /* private fields */ }Expand description
Catalog (admin) client for a transactor endpoint.
Implementations
Sourceimpl Admin
impl Admin
Sourcepub async fn connect(
endpoint: &str,
token: Option<String>,
tls: Option<ClientTlsConfig>,
) -> Result<Self, PeerError>
pub async fn connect( endpoint: &str, token: Option<String>, tls: Option<ClientTlsConfig>, ) -> Result<Self, PeerError>
Sourcepub async fn create_database(
&mut self,
db: &str,
schema: &[Edn],
) -> Result<bool, PeerError>
pub async fn create_database( &mut self, db: &str, schema: &[Edn], ) -> Result<bool, PeerError>
Sourcepub async fn fork_database(
&mut self,
db: &str,
target: &str,
as_of_t: Option<u64>,
) -> Result<Option<u64>, PeerError>
pub async fn fork_database( &mut self, db: &str, target: &str, as_of_t: Option<u64>, ) -> Result<Option<u64>, PeerError>
Forks db into a new database target duplicating it at
transaction basis as_of_t (None forks at the current basis).
Returns the fork’s basis, or None when the target already existed.
Errors
Returns PeerError on transport failure, an unknown source, an
invalid target name, or a basis ahead of the source’s.
Sourcepub async fn gc_deleted_databases(&mut self) -> Result<u64, PeerError>
pub async fn gc_deleted_databases(&mut self) -> Result<u64, PeerError>
Sourcepub async fn gc_deleted_databases_with_retention(
&mut self,
retention: Option<Duration>,
) -> Result<u64, PeerError>
pub async fn gc_deleted_databases_with_retention( &mut self, retention: Option<Duration>, ) -> Result<u64, PeerError>
Sourcepub async fn set_index_policy(
&mut self,
db: &str,
update: IndexPolicySettings,
) -> Result<IndexPolicySettings, PeerError>
pub async fn set_index_policy( &mut self, db: &str, update: IndexPolicySettings, ) -> Result<IndexPolicySettings, PeerError>